Coverage for /Users/mschultzberg/PycharmProjects/confidence/spotify_confidence/analysis/abstract_base_classes/confidence_grapher_abc.py: 89%

# Coverage for /Users/mschultzberg/PycharmProjects/confidence/spotify_confidence/analysis/abstract_base_classes/confidence_grapher_abc.py : 89%

## 18 statements 16 run 2 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 | # Copyright 2017-2020 Spotify AB # # Licensed under the Apache License, Version 2.0 (the "License"); # you may not use this file except in compliance with the License. # You may obtain a copy of the License at # # http://www.apache.org/licenses/LICENSE-2.0 # # Unless required by applicable law or agreed to in writing, software # distributed under the License is distributed on an "AS IS" BASIS, # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. # See the License for the specific language governing permissions and # limitations under the License. from abc import ABC, abstractmethod from typing import Union, Iterable from pandas import DataFrame from spotify_confidence.chartgrid import ChartGrid from ..constants import NIM_TYPE class ConfidenceGrapherABC(ABC): @abstractmethod def __init__(self, data_frame: DataFrame, numerator_column: str, denominator_column: str, categorical_group_columns: str, ordinal_group_column: str): pass @abstractmethod def plot_summary(self, summary_df: DataFrame, groupby: Union[str, Iterable]) -> ChartGrid: """Plot for each group in the data_frame: if ordinal level exists: line graph with area to represent confidence interval if categorical levels: Interval plots of confidence intervals by group Args: summary_df (DataFrame): A data frame produced by a ConfidenceComputer's summary method Returns: ChartGrid object. """ pass @abstractmethod def plot_difference(self, difference_df: DataFrame, absolute: bool, groupby: Union[str, Iterable], nims: NIM_TYPE, use_adjusted_intervals: bool ) -> ChartGrid: """Plot representing the difference between group 1 and 2 with confidence intervals. Args: difference_df (DataFrame): A dataframe produced by a ConfidenceComputer's difference method Returns: Chartify Chart object. :param groupby: """ @abstractmethod def plot_differences(self, difference_df: DataFrame, absolute: bool, groupby: Union[str, Iterable], nims: NIM_TYPE, use_adjusted_intervals: bool ) -> ChartGrid: """Plot representing the difference between group 1 and 2 with confidence intervals. Args: difference_df (DataFrame): A dataframe produced by a ConfidenceComputer's difference method Returns: Chartify Chart object. :param groupby: """ @abstractmethod def plot_multiple_difference(self, difference_df: DataFrame, absolute: bool, groupby: Union[str, Iterable], level_as_reference: bool, nims: NIM_TYPE, use_adjusted_intervals: bool ) -> ChartGrid: """Compare level to all other groups or, if level_as_reference = True, all other groups to level. Args: difference_df (DataFrame): A dataframe produced by a ConfidenceComputer's multiple_difference method Returns: ChartGrid object. """